<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package samantha
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<!-- comments -->
<div class="comments gap no-bottom" data-aos="fade-up" data-aos-delay="200" data-aos-duration="400">

		<div id="comments" class="post-comments">

		<?php
		// You can start editing here -- including this comment!
		if ( have_comments() ) :
		?>

		<h3><?php comments_number( esc_html__( 'No comments found', 'samantha' ), esc_html__( '1 Comment', 'samantha' ), esc_html__( '% Comments', 'samantha' ) ); ?></h3>
		
		<!-- comments -->
		<ul class="smth-comments-list">
			<?php
			wp_list_comments( array(
				'style'	  => 'ul',
				'avatar_size' => '80',
				'callback' => 'samantha_comment'
			) );
			?>
		</ul>

		<?php
		the_comments_navigation( array(
			'screen_reader_text' => ' ',
			'prev_text' => esc_html__( 'Older comments', 'samantha' ),
			'next_text' => esc_html__( 'Newer comments', 'samantha' )
		) );

		// If comments are closed and there are comments, let's leave a little note, shall we?
		if ( ! comments_open() ) :
		?>
		<p class="smth-text no-comments"><?php esc_html_e( 'Comments are closed.', 'samantha' ); ?></p>
		<?php endif; ?>

		<?php endif; // Check for have_comments().
		?>

		<div class="about-form comment-text form-comment <?php if ( comments_open() ) : ?>form-comment-open<?php endif; ?>" data-aos="fade-up" data-aos-delay="200" data-aos-duration="400">
			<?php
				$req = get_option( 'require_name_email' );
				$aria_req = ( $req ? " aria-required='true'" : '' );

				$comment_args = array(
					'title_reply' => esc_html__( 'Write a comment', 'samantha' ),
					'title_reply_to' => esc_html__( 'Write a comment to %s', 'samantha' ),
					'cancel_reply_link' => esc_html__( 'Cancel Reply', 'samantha' ),
					'title_reply_before' => '<div id="reply-title" class="title comment-reply-title"><h3 class="sb-mb-60">',
					'title_reply_after' => '</h3></div>',
					'label_submit' => esc_html__( 'Submit', 'samantha' ),
					'comment_field' => '<div class="smth-group-input"><textarea placeholder="' . esc_attr__( 'Comment', 'samantha' ).'" id="comment" name="comment" aria-required="true" ></textarea></div>',
					'must_log_in' => '<p class="smth-text smth-mb-30 must-log-in">' . esc_html__( 'You must be ', 'samantha' ) . '<a href="' . esc_url( wp_login_url( apply_filters( 'the_permalink', get_permalink( ) ) ) ) . '">' . esc_html__( 'logged in', 'samantha' ) . '</a>' . esc_html__( ' to post a comment.', 'samantha' ) . '</p>',
					'logged_in_as' => '<p class="smth-text smth-mb-30 logged-in-as">' . esc_html__( 'Logged in as ', 'samantha' ) . '<a href="' . esc_url( admin_url( 'profile.php' ) ) . '">' . esc_html( $user_identity ) . '</a>' . esc_html__( '. ', 'samantha' ) . '<a href="' . esc_url( wp_logout_url( apply_filters( 'the_permalink', get_permalink( ) ) ) ) . '" title="' . esc_attr__( 'Log out of this account', 'samantha' ) . '">' . esc_html__( 'Log out?', 'samantha' ) . '</a></p>',
					'comment_notes_before' => '',
					'comment_notes_after' => '',
					'fields' => apply_filters( 'comment_form_default_fields', array(
						'author' => '<div class="smth-group-input"><input id="author" name="author" type="text" placeholder="' . esc_attr__( 'Name', 'samantha' ) . '" value="" ' . $aria_req . ' /></div>',
						'email' => '<div class="smth-group-input"><input id="email" name="email" type="text" placeholder="' . esc_attr__( 'Email', 'samantha' ) . '" value="" ' . $aria_req . ' /></div>',
					)),
					'class_submit' => 'button',
					'submit_field' => '<div class="form-comment-submit">%1$s %2$s</div>',
					'submit_button' => '<button type="submit" name="%1$s" id="%2$s" class="%3$s"><span>%4$s</span></button>'
				);

				comment_form( $comment_args );
			?>
		</div>

		</div>
		
</div>
<!-- comments end -->
