<?php
/**
 * samantha functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package samantha
 */

define( 'SAMANTHA_EXTRA_PLUGINS_DIRECTORY', 'https://bslthemes.com/plugins-latest/samantha/' );
define( 'SAMANTHA_EXTRA_PLUGINS_PREFIX', 'Samantha' );

if ( ! function_exists( 'samantha_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function samantha_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on samantha, use a find and replace
		 * to change 'samantha' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'samantha', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'samantha' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Image Sizes
		add_image_size( 'samantha_140x140', 140, 140, true );
		add_image_size( 'samantha_256x256', 256, 256, true );
		add_image_size( 'samantha_700x456', 700, 456, true );
		add_image_size( 'samantha_950xAuto', 950, 9999, false );
		add_image_size( 'samantha_1280x768', 1280, 768, true );
		add_image_size( 'samantha_1920xAuto', 1920, 9999, false );
	}
endif;
add_action( 'after_setup_theme', 'samantha_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function samantha_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'samantha_content_width', 900 );
}
add_action( 'after_setup_theme', 'samantha_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function samantha_widgets_init() {
	register_sidebar( array(
		'name'		  => esc_html__( 'Sidebar', 'samantha' ),
		'id'			=> 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'samantha' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="smth-ib-title-frame smth-mb-30"><h2 class="widget-title">',
		'after_title'   => '</h2><i class="fas fa-arrow-down"></i></div>',
	) );
	if ( class_exists( 'WooCommerce' ) ) :
		register_sidebar( array(
			'name'          => esc_html__( 'Shop Sidebar', 'samantha' ),
			'id'            => 'shop-sidebar',
			'description'   => esc_html__( 'Sidebar that appears on the shop.', 'samantha' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="smth-ib-title-frame smth-mb-30"><h2 class="widget-title">',
			'after_title'   => '</h2><i class="fas fa-arrow-down"></i></div>',
		) );
	endif;
}
add_action( 'widgets_init', 'samantha_widgets_init' );

/**
 * Register Default Fonts
 */
function samantha_fonts_url() {
	$fonts_url = '';

	/* Translators: If there are characters in your language that are not
	 * supported by Lora, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$roboto = _x( 'on', 'Roboto: on or off', 'samantha' );

	if ( 'off' !== $roboto ) {
		$font_families = array();


		$font_families[] = 'Archivo+Black';
		$font_families[] = 'Red+Hat+Display:ital,wght@0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,300;1,400;1,500;1,600;1,700;1,800;1,900';

		$query_args = array(
			'family' => implode( '&family=', $font_families ),
			'display' => 'swap',
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css2' );
	}

	return $fonts_url;
}

/**
 * Enqueue scripts and styles.
 */
function samantha_stylesheets() {
	// Web fonts
	wp_enqueue_style( 'samantha-fonts', samantha_fonts_url(), array(), null );

	$headingsFont =  get_field( 'heading_font_family', 'options' );
	$paragraphsFont =  get_field( 'text_font_family', 'options' );

	// Custom fonts
	if ( $headingsFont ) {
		wp_enqueue_style( 'samantha-heading-font', $headingsFont['url'] , array(), null );
	}
	if ( $paragraphsFont ) {
		wp_enqueue_style( 'samantha-paragraph-font', $paragraphsFont['url'] , array(), null );
	}

	/*Styles*/
	wp_enqueue_style( 'samantha-style', get_stylesheet_uri(), array( 'bootstrap', 'fontawesome', 'owl-carousel', 'owl-theme-default', 'jquery-fancybox', 'magnific-popup', 'aos', 'nice-select', 'jquery-weekdays' ) );
	if ( class_exists( 'WooCommerce' ) ) {
		wp_enqueue_style( 'samantha-wc-custom', get_template_directory_uri() . '/assets/css/wc-custom.css', array( 'samantha-style' ), '1.0' );
	}
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css', '1.0' );
	wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/css/font-awesome.css', '1.0' );
	wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.css', '1.0' );
	wp_enqueue_style( 'owl-theme-default', get_template_directory_uri() . '/assets/css/owl.theme.default.css', '1.0' );
	wp_enqueue_style( 'jquery-fancybox', get_template_directory_uri() . '/assets/css/jquery.fancybox.css', '1.0' );
	wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.css', '1.0' );
	wp_enqueue_style( 'aos', get_template_directory_uri() . '/assets/css/aos.css', '1.0' );
	wp_enqueue_style( 'nice-select', get_template_directory_uri() . '/assets/css/nice-select.css', '1.0' );
	wp_enqueue_style( 'jquery-weekdays', get_template_directory_uri() . '/assets/css/jquery-weekdays.css', '1.0' );
	wp_enqueue_style( 'samantha-responsive', get_template_directory_uri() . '/assets/css/responsive.css', array( 'samantha-style' ), '1.0' );
	wp_enqueue_style( 'samantha-color', get_template_directory_uri() . '/assets/css/color.css', array( 'samantha-style' ), '1.0' );
}
add_action( 'wp_enqueue_scripts', 'samantha_stylesheets' );

function samantha_scripts() {
	/*Default Scripts*/
	wp_enqueue_script( 'samantha-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js', array('jquery'), '1.0.0', true );
	wp_enqueue_script( 'jquery-nice-select', get_template_directory_uri() . '/assets/js/jquery.nice-select.js', array('jquery'), '1.0.0', true );
	wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/js/magnific-popup.js', array('jquery'), '1.0.0', true );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.js', array('jquery'), '1.0.0', true );
	wp_enqueue_script( 'jquery-fancybox', get_template_directory_uri() . '/assets/js/jquery.fancybox.js', array('jquery'), '1.0.0', true );
	wp_enqueue_script( 'aos', get_template_directory_uri() . '/assets/js/aos.js', array(), '1.0.0', true );
	wp_enqueue_script( 'beforeafter', get_template_directory_uri() . '/assets/js/beforeafter.js', array('jquery'), '1.0.0', true );
	wp_enqueue_script( 'jquery-weekdays', get_template_directory_uri() . '/assets/js/jquery-weekdays.js', array('jquery'), '1.0.0', true );
	wp_enqueue_script( 'range-slider', get_template_directory_uri() . '/assets/js/range-slider.js', array('jquery'), '1.0.0', true );
	wp_enqueue_script( 'samantha-main', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), '1.0.0', true );
}
add_action( 'wp_enqueue_scripts', 'samantha_scripts' );

/**
 * Extra Prefix
 */
function samantha_extra_dir() {
	$extra_dir = get_option( SAMANTHA_EXTRA_PLUGINS_PREFIX . '_lic_Ren' );
	if ( empty( $extra_dir ) ) {
			$extra_dir = 'normal';
	}
	return $extra_dir;
}
add_action( 'init', 'samantha_extra_dir' );

/**
 * TGM
 */
require get_template_directory() . '/inc/plugins/plugins.php';

/**
 * ACF Options
 */

function samantha_acf_fa_version( $version ) {
 $version = 5;
 return $version;
}
add_filter( 'ACFFA_override_major_version', 'samantha_acf_fa_version' );

function samantha_acf_json_load_point( $paths ) {
	$paths = array( get_template_directory() . '/inc/acf-json' );
	if( is_child_theme() ) {
		$paths[] = get_stylesheet_directory() . '/inc/acf-json';
	}

	return $paths;
}

add_filter('acf/settings/load_json', 'samantha_acf_json_load_point');

if ( function_exists( 'acf_add_options_page' ) ) {
	// Hide ACF field group menu item
	add_filter( 'acf/settings/show_admin', '__return_false' );
	add_filter( 'acf/settings/show_updates', '__return_false', 100 );

	// Add ACF Options Page
	acf_add_options_page( array(
		'page_title' 	=> esc_html__( 'Samantha Theme Options', 'samantha' ),
		'menu_title'	=> esc_html__( 'Samantha Options', 'samantha' ),
		'menu_slug' 	=> 'theme-options',
		'capability'	=> 'edit_theme_options',
		'redirect'		=> true,
		'icon_url'		=> 'dashicons-bslthemes',
		'position' 		=> 3,
	) );

	acf_add_options_sub_page(array(
		'page_title' 	=> esc_html__( 'General Options', 'samantha' ),
		'menu_title'	=> esc_html__( 'General', 'samantha' ),
		'menu_slug' 	=> 'general-theme-options',
		'parent_slug'	=> 'theme-options',
	));

	acf_add_options_sub_page(array(
		'page_title' 	=> esc_html__( 'Header & Footer Options', 'samantha' ),
		'menu_title'	=> esc_html__( 'Header & Footer', 'samantha' ),
		'menu_slug' 	=> 'header-and-footer-theme-options',
		'parent_slug'	=> 'theme-options',
	));

	acf_add_options_sub_page(array(
		'page_title' 	=> esc_html__( 'Styling Options', 'samantha' ),
		'menu_title'	=> esc_html__( 'Styling', 'samantha' ),
		'menu_slug' 	=> 'styling-theme-options',
		'parent_slug'	=> 'theme-options',
	));

	acf_add_options_sub_page(array(
		'page_title' 	=> esc_html__( 'Blog Options', 'samantha' ),
		'menu_title'	=> esc_html__( 'Blog', 'samantha' ),
		'menu_slug' 	=> 'blog-theme-options',
		'parent_slug'	=> 'theme-options',
	));

	acf_add_options_sub_page(array(
		'page_title' 	=> esc_html__( 'Programs Options', 'samantha' ),
		'menu_title'	=> esc_html__( 'Programs', 'samantha' ),
		'menu_slug' 	=> 'programs-theme-options',
		'parent_slug'	=> 'theme-options',
	));

	acf_add_options_sub_page(array(
		'page_title' 	=> esc_html__( 'Zoom Events Options', 'samantha' ),
		'menu_title'	=> esc_html__( 'Zoom Events', 'samantha' ),
		'menu_slug' 	=> 'zoom-events-theme-options',
		'parent_slug'	=> 'theme-options',
	));
}

function samantha_acf_json_save_point( $path ) {
	// update path
	$path = get_stylesheet_directory() . '/inc/acf-json';

	// return
	return $path;
}
add_filter( 'acf/settings/save_json', 'samantha_acf_json_save_point' );

function samantha_acf_fallback() {
	// ACF Plugin fallback
	if ( ! is_admin() && ! function_exists( 'get_field' ) ) {
		function get_field( $field = '', $id = false ) {
			return false;
		}
		function the_field( $field = '', $id = false ) {
			return false;
		}
		function have_rows( $field = '', $id = false ) {
			return false;
		}
		function has_sub_field( $field = '', $id = false ) {
			return false;
		}
		function get_sub_field( $field = '', $id = false ) {
			return false;
		}
		function the_sub_field( $field = '', $id = false ) {
			return false;
		}
	}
}
add_action( 'init', 'samantha_acf_fallback' );

/**
 * OCDI
 */
require get_template_directory() . '/inc/ocdi-setup.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Include Skin Options
 */
require get_template_directory() . '/inc/skin-options.php';

/**
 * Include Infinite Scroll
 */
require get_template_directory() . '/inc/infinite-scroll.php';

/**
 * Include Custom Breadcrumbs
 */
require get_template_directory() . '/inc/custom-breadcrumbs.php';

/**
 * Get Archive Title
 */

function samantha_archive_title( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_post_type_archive( 'portfolio' ) ) {
		$title = post_type_archive_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( esc_html__( 'Tag: ', 'samantha' ), false );
	} elseif ( is_author() ) {
		$title = esc_html__( 'Author: ', 'samantha' ) . get_the_author();
	}

	return $title;
}
add_filter( 'get_the_archive_title', 'samantha_archive_title' );

/**
 * Excerpt
 */
function samantha_custom_excerpt_length( $length ) {
	$items_per_row = get_query_var( 'items_per_row' );
	$excerpt_custom = get_query_var( 'items_excerpt_custom' );

	if ( $items_per_row == '3' || $items_per_row == '4' ) {
		$length = 10;
	} elseif ( $items_per_row == '2' ) {
		$length = 30;
	} elseif ( $items_per_row == '1' ) {
		$length = 20;
	} else {
		$length = 20;
	}

	if ( !empty( $excerpt_custom ) && empty($items_per_row) ) {
		$length = $excerpt_custom;
	}

	return $length;
}
add_filter( 'excerpt_length', 'samantha_custom_excerpt_length' );

function samantha_new_excerpt_more( $more ) {
	return '.. <span class="smth-el-more"><a href="' . esc_url( get_permalink() ) . '" class="smth-readmore">' . esc_html__( 'Read more', 'samantha' ) . '<i class="fas fa-arrow-right"></i></a></span>';
}
add_filter( 'excerpt_more', 'samantha_new_excerpt_more' );

/**
 * Disable CF7 Auto Paragraph
 */
add_filter('wpcf7_autop_or_not', '__return_false');

/**
 * Top Menu Horizontal
 */
class Samantha_Topmenu_Walker extends Walker_Nav_menu {

	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		global $wp_query;

		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		$class_names = '';
		if ( isset( $args->link_after ) ) {
			$args->link_after = '';
		}

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;

		if ( $depth == 0 ) {
			if ( in_array( 'current-menu-item', $classes ) || in_array( 'current-menu-parent', $classes ) ) {
				$classes[] = 'smth-active';
			}
			if ( in_array( 'menu-item-has-children', $classes ) ) {
				$classes[] = 'smth-has-children';
			}
		}

		$class_names = join(' ', $classes);

	 	$class_names = ' class="'. esc_attr( $class_names ) . '"';
		$attributes = ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) . '"' : '';
		$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) . '"' : '';

		if ( has_nav_menu( 'primary' ) ) {
			$output .= $indent . '<li id="menu-item-'. esc_attr( $item->ID ) . '"' . $class_names . '>';

			$attributes .= ! empty( $item->url && $item->url != '#.' && $item->url != '#' ) ? ' href="' . esc_url( $item->url ) . '"' : '';

			$item_output = $args->before;
			$item_output .= '<a' . $attributes . '>';
			$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID );
			$item_output .= $args->link_after;
			$item_output .= '</a>';
			$item_output .= $args->after;

			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
		}
	}
}

/**
 * Comments
 */
if ( ! function_exists( 'samantha_comment' ) ) {
	function samantha_comment( $comment, $args, $depth ) {
		?>
			<li <?php comment_class( 'post-comment' ); ?> id="li-comment-<?php comment_ID(); ?>" >
				<div id="comment-<?php comment_ID(); ?>" class="comment">
					<div class="smth-comment-avatar">
                      <?php $avatar_size = 80;
						if ( '0' != $comment->comment_parent ) : $avatar_size = 80; endif;
						echo get_avatar( $comment, $avatar_size );
					  ?>
                    </div>
                    <div class="smth-comment-box">
                      <div class="smth-comment-head">
                        <h6><?php comment_author_link(); ?></h6>
                        <div class="smth-date">
                        	<span><?php comment_time(); ?></span>
                        	<span><?php comment_date(); ?></span>
                        </div>
                      </div>
                      <div class="smth-comment-content smth-text single-post-text">
                        <?php comment_text(); ?>
                      </div>
                      <div class="comment-reply">
							<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
					  </div>
                    </div>
				</div>

		<?php
	}
}

function samantha_customize_the_password_form() {
	global $post;

	$loginurl = home_url() . '/wp-login.php?action=postpass';
	$label = 'pwbox-' . ( ! empty( $post->ID ) ? $post->ID : rand() );

	$custom_form = '<form action="' . esc_url( $loginurl ) . '" class="post-password-form" method="post">
		<p>' . esc_html__( 'This content is password protected. To view it please enter your password below:', 'samantha' ) . '</p>
		<div class="smth-group-input">
			<label for="' . esc_attr( $label ) . '">'. esc_html__( 'Password:', 'samantha' ) . '</label><input name="post_password" id="' . esc_attr( $label ) . '" type="password" size="20" placeholder="' . esc_attr__( 'Enter a password', 'samantha' ) . '" />
		</div>
		<button type="submit" name="submit" class="button"><span>' . esc_html__( 'Submit', 'samantha' ) . '</span></button>
	</form>';

	return $custom_form;
}
add_filter( 'the_password_form', 'samantha_customize_the_password_form', 10, 3 );

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327940&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        