<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package samantha
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<!-- Meta Data -->
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
	<?php wp_body_open(); ?>

	<?php 
	$preloader = get_field( 'preloader', 'option' ); 
	$preloader_label = get_field( 'preloader_label', 'option' );
	?>

	<?php if ( ! $preloader ) : ?>
	<div class="page-loader">
		<div class="spinner"></div>
		<div class="txt">
			<?php if ( $preloader_label ) : echo esc_html( $preloader_label ); else : echo esc_html__( 'Loading...', 'samantha' ); endif; ?>
		</div>
	</div>
	<?php endif; ?>

	<header class="header">
		<?php
			$header_template = get_field( 'header_template', 'option' );

			if ( $header_template ) :
				$args = array( 'post_type' => 'hf_templates', 'p' => $header_template );
				$loop = new WP_Query( $args );
				while ( $loop->have_posts() ) : $loop->the_post();
					the_content();
				endwhile; wp_reset_postdata();
			else :
		?>

		<div class="container">
    		<div class="row align-items-center">
        		<div class="col-lg-2">
          			<div class="logo-icon">
            			<a href="<?php echo esc_url( home_url() ); ?>">
							<span class="logotype__title"><?php echo esc_html( bloginfo('name') ); ?></span>
							<span class="logotype__sub"><?php echo esc_html( bloginfo('description') ); ?></span>
            			</a>
            			<span class="bar-menu"></span>
          			</div>
         		</div>
         		<div class="col-lg-10">
           			<div class="menu-bar">
						<?php
						if ( has_nav_menu( 'primary' ) ) :
							wp_nav_menu( array(
								'theme_location' => 'primary',
								'container' => 'nav',
								'container_class' => '',
								'menu_class' => 'smth-navigation',
								'walker' => new Samantha_Topmenu_Walker(),
							) );
						endif; ?>
           			</div>
         		</div>
    		</div>
    	</div>

		<?php endif; ?>
		
		<?php $popup1_template = get_field( 'popup1_template', 'option' ); 
		if ( $popup1_template ) : ?>

    	<div class="container">
      		<div class="row">
        		<div class="menu-wrap">
             		<div class="menu-inner ps ps--active-x ps--active-y">
                 		<span class="menu-cls-btn"><i class="cls-leftright"></i><i class="cls-rightleft"></i></span>
                 		<div class="hambur">
						 	<?php $args = array( 'post_type' => 'hf_templates', 'p' => $popup1_template );
							$loop = new WP_Query( $args );
							while ( $loop->have_posts() ) : $loop->the_post();
								the_content();
							endwhile; wp_reset_postdata(); ?>
                 		</div>
             		</div>
                </div>
    		</div>
    	</div>

		<?php endif; ?>
		
		<?php 
		
		$mob_nav_logo = get_field( 'mob_nav_logo', 'option' );
		$mob_nav_info = get_field( 'mob_nav_info', 'option' ); 

		?>

    	<div class="mobile-nav" id="mobile-nav">
			<?php if ( $mob_nav_logo ) : ?>
        	<div class="res-log">
          		<a href="<?php echo esc_url( home_url() ); ?>">
            		<img src="<?php echo esc_url( $mob_nav_logo ); ?>" alt="<?php echo esc_attr( bloginfo('name') ); ?>" />
          		</a>
        	</div>
			<?php endif; ?>

        	<ul class="sth-navigation"></ul>

			<?php if ( $mob_nav_info ) : ?>
        	<ul class="Contacts mobil">
			  <?php foreach ( $mob_nav_info as $item ) : ?>
        	  <li>
				<a href="<?php echo esc_attr( $item['link'] ); ?>">
					<span class="icon">
						<?php echo wp_kses_post( $item['icon'] ); ?>
			  		</span>
					<?php echo esc_html( $item['text'] ); ?>
				</a>
			  </li>
			  <?php endforeach; ?>
        	</ul>
			<?php endif; ?>
      		<span  class="res-cross"><i class="cls-leftright"></i><i class="cls-rightleft"></i></span>
    	</div>
  	</header>
