<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package samantha
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function samantha_body_classes( $classes ) {
	// Add default class menu
	$classes[] = 'menu-layer';

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	$header_template = get_field( 'header_template', 'option' );

	if ( empty( get_field( 'header_template', 'option' ) ) ) {
		$classes[] = 'smth-default';
	}

	return $classes;
}
add_filter( 'body_class', 'samantha_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function samantha_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'samantha_pingback_header' );
