<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package samantha
 */

if ( ! function_exists( 'samantha_after_content' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and share buttons.
	 */
	function samantha_after_content() {
		if ( shortcode_exists( 'shared_counts' ) ) :
			echo do_shortcode( '[shared_counts]' );
		endif;
		
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'samantha' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<div class="blog-img-details cat-links">' . esc_html__( 'Posted in %1$s', 'samantha' ) . '</div>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( '', 'list item separator', 'samantha' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<div class="blog-img-details tags-links">' . esc_html__( 'Tags: %1$s', 'samantha' ) . '</div>', $tags_list ); // WPCS: XSS OK.
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<div class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'samantha' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</div>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'samantha' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<div class="edit-link">',
			'</div>'
		);
	}
endif;

if ( ! function_exists( 'samantha_after_title' ) ) :
	/**
	 * Prints HTML with meta information for the current post.
	 */
	function samantha_after_title() { ?>
		<div class="share">
			<h5>
				<span><?php echo esc_html__( 'By', 'samantha' ); ?></span>
				<?php echo esc_html( get_the_author() ); ?>
			</h5>
			<h6>
				<i class="far fa-calendar-alt"></i>
				<?php echo esc_html( get_the_date() ); ?>
			</h6>
			<?php if ( shortcode_exists( 'shared_counts' ) ) : ?>
			<div class="h6">
				<i class="fas fa-share"></i>
				<?php echo do_shortcode( '[shared_counts]' ); ?>
			</div>
			<?php endif; ?>
			<h6>
				<i class="far fa-comment-alt"></i>
				<?php echo esc_html( comments_number() ); ?>
			</h6>
		</div>
	<?php }
endif;

if ( ! function_exists( 'samantha_single_navigantion' ) ) :
	/**
	 * Displays an optional prev/next/all nagigations.
	 */
	function samantha_single_navigantion() {
		if ( is_singular() ) :

			$prev_post = get_adjacent_post( false, '', true );
			$next_post = get_adjacent_post( false, '', false );
			$archive_url = false;
			$archive_page_id = get_field( get_post_type() . '_page', 'option' );
			if ( ! $archive_page_id ) {
				$archive_url = get_post_type_archive_link( get_post_type() );
			} else {
				$archive_url = get_permalink( $archive_page_id );
			}

			$prev_str = esc_html__( 'Previous post', 'samantha' );
			$next_str = esc_html__( 'Next Post', 'samantha' );
			$all_str = esc_html__( 'All posts', 'samantha' );

		?>

		<div class="previou-next">
			<div class="previou">
				<?php if ( is_a( $prev_post, 'WP_Post' ) ) : ?>
				<div class="previous-post">
					<?php $image = get_the_post_thumbnail_url( $prev_post->ID, 'samantha_900xAuto' ); ?>
					<?php if ( $image ) : ?>
					<img alt="<?php echo esc_attr( get_the_title( $prev_post->ID ) ); ?>" src="<?php echo esc_url( $image ); ?>" />
					<?php endif; ?>
				</div>
				<div>
					<h6><?php echo wp_kses_post( get_the_title( $prev_post->ID ) ); ?></h6>
					<a href="<?php echo esc_url( get_permalink( $prev_post->ID ) ); ?>"><i class="fas fa-angle-left"></i><?php echo esc_html( $prev_str ); ?></a>
				</div>
				<?php endif; ?>
			</div>
			<div class="previou next-post">
				<?php if ( is_a( $next_post, 'WP_Post' ) ) : ?>
				<div>
					<h6><?php echo wp_kses_post( get_the_title( $next_post->ID ) ); ?></h6>
					<a href="<?php echo esc_url( get_permalink( $next_post->ID ) ); ?>"><?php echo esc_html( $next_str ); ?><i class="fas fa-angle-right"></i></a>
				</div>
				<div class="previous-post">
					<?php $image = get_the_post_thumbnail_url( $next_post->ID, 'samantha_900xAuto' ); ?>
					<?php if ( $image ) : ?>
					<img alt="<?php echo esc_attr( get_the_title( $next_post->ID ) ); ?>" src="<?php echo esc_url( $image ); ?>" />
					<?php endif; ?>
				</div>
				<?php endif; ?>
			</div>
		</div>

		<?php
		endif; // End is_singular().
	}
endif;

if ( ! function_exists( 'samantha_single_author_details' ) ) :
	/**
	 * Displays an optional author section.
	 */
	function samantha_single_author_details() {
		if ( is_singular() ) :

			$author_details = get_field( 'author_details', 'option' );
			if ( ! empty( $author_details ) ) : if ( $author_details['enabled'] == 1 ) :
		?>

		<div class="hana-evans" data-aos="fade-up" data-aos-delay="200" data-aos-duration="300">
			<div class="blog-detai">
				<?php $image = wp_get_attachment_image_url( $author_details['image'], 'samantha_950xAuto' ); ?>
				<?php if ( $image ) : ?>
				<img alt="<?php echo esc_attr( $author_details['name'] ); ?>" src="<?php echo esc_url( $image ); ?>" />
				<?php endif; ?>
			</div>
			<div>
				<?php if ( $author_details['name'] ) : ?>
				<h4><?php echo esc_html( $author_details['name'] ); ?></h4>
				<?php endif; ?>
				<?php if ( $author_details['description'] ) : ?>
				<p><?php echo wp_kses_post( $author_details['description'] ); ?></p>
				<?php endif; ?>
				<?php if ( $author_details['social'] ) : $author_social = $author_details['social']; ?>
				<ul class="social-icons">
					<?php foreach ( $author_social as $item ) : ?>
					<li>
						<a href="<?php echo esc_url( $item['link'] ); ?>" target="_blank" title="<?php echo esc_attr( $item['title'] ); ?>">
							<?php echo wp_kses_post( $item['icon'] ); ?>
						</a>
					</li>
					<?php endforeach?>
				</ul>
				<?php endif; ?>
			</div>
		</div>

		<?php
		endif; endif;
		endif; // End is_singular().
	}
endif;
